@@ -24,6 +24,15 @@ from .cmssw import CMSSW
 from .cmssw_releases import get_arch
 import seutils
 
+
+# ___________________________________________________
+# Decisions at import-time depending on whether this is a job or
+# an import on an interactive node
+
+if BATCHMODE:
+    # Sets default amount of times to retry a seutils.cp statement
+    seutils.N_COPY_RETRIES = 2
+
 # Read cached ls calls if this is a job
 if BATCHMODE and osp.isfile(Preprocessor.LS_CACHE_FILE):
     Preprocessor.read_ls_cache(Preprocessor.LS_CACHE_FILE)
@@ -32,8 +41,10 @@ if BATCHMODE and osp.isfile(Preprocessor.LS_CACHE_FILE):
 if BATCHMODE and osp.isfile('rootcache.tar.gz'):
     seutils.root.load_cache('rootcache.tar.gz')
 
+# FNAL-specific things
 if os.environ.get('HOSTNAME', '').endswith('fnal.gov'):
     # Fix to be able to import htcondor python bindings
+    logger.warning('Detected FNAL: Modifying path to use system htcondor python bindings')
     import sys
     if sys.version_info.major < 3:
         sys.path.extend([
@@ -44,6 +55,15 @@ if os.environ.get('HOSTNAME', '').endswith('fnal.gov'):
     seutils.set_default_mgm('root://cmseos.fnal.gov')
 
 
+# ___________________________________________________
+# 'Globals'
+
+DRYMODE = False
+def drymode(flag=True):
+    global DRYMODE
+    DRYMODE = flag
+
+
 # ___________________________________________________
 # Short cuts
 
